==> jc-1.4.0.tar.gz: soot/jimple/spark/internal/BDDTypeManager.h <==
// public final class soot.jimple.spark.internal.BDDTypeManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager
// @dep_class 699fc0710c61578 soot_jimple_spark_internal_BDDTypeManager

// header file dependencies
// @dep_header soot_jimple_spark_internal_AbstractTypeManager

#include "soot/jimple/spark/internal/AbstractTypeManager.h"

#ifndef _JC_soot_jimple_spark_internal_BDDTypeManager_H_
#define _JC_soot_jimple_spark_internal_BDDTypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_relations_Domain$object;
struct _jc_soot_relations_PhysicalDomain$object;
struct _jc_soot_relations_Relation$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs	_jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$refs	_jc_soot_jimple_spark_internal_BDDTypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs	_jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$object	_jc_soot_jimple_spark_internal_BDDTypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vmethods	_jc_soot_jimple_spark_internal_BDDTypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtable	_jc_soot_jimple_spark_internal_BDDTypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtype	_jc_soot_jimple_spark_internal_BDDTypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$_init$a580f473db5d2f29(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
extern struct _jc_soot_relations_Relation$object *_jc_soot_jimple_spark_internal_BDDTypeManager$method$get$f657e2659e21a4a6(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$update$1bc19abd93504b5c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$updatePair$01330770c59dda9c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$get$f657e2659e21a4a6;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$makeTypeMask$f36568e0574d6282;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$update$1bc19abd93504b5c;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$updatePair$01330770c59dda9c;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vmethods {
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
	struct _jc_soot_relations_Relation$object	*(*get$f657e2659e21a4a6)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
	void	(*update$1bc19abd93504b5c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *);
	void	(*updatePair$01330770c59dda9c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vmethods	soot_jimple_spark_internal_BDDTypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs {
	struct _jc_soot_relations_PhysicalDomain$object	*t1;
	struct _jc_soot_relations_PhysicalDomain$object	*t2;
	struct _jc_soot_relations_PhysicalDomain$object	*v1;
	struct _jc_soot_relations_PhysicalDomain$object	*h1;
	struct _jc_soot_relations_Domain$object	*subt;
	struct _jc_soot_relations_Domain$object	*supt;
	struct _jc_soot_relations_Domain$object	*type;
	struct _jc_soot_relations_Domain$object	*var;
	struct _jc_soot_relations_Domain$object	*obj;
	struct _jc_soot_relations_Relation$object	*typeSubtype;
	struct _jc_soot_relations_Relation$object	*varNodeType;
	struct _jc_soot_relations_Relation$object	*newVnType;
	struct _jc_soot_relations_Relation$object	*allocNodeType;
	struct _jc_soot_relations_Relation$object	*newAnType;
	struct _jc_soot_relations_Relation$object	*typeMask;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$refs {
    _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs	soot_jimple_spark_internal_BDDTypeManager;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs {
	jint	lastAllocNode;
	jint	lastVarNode;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs	soot_jimple_spark_internal_BDDTypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_BDDTypeManager$object {
	_jc_soot_jimple_spark_internal_BDDTypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_BDDTypeManager$vtype _jc_soot_jimple_spark_internal_BDDTypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_BDDTypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_BDDTypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_BDDTypeManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/internal/BDDTypeManager.h <==
// public final class soot.jimple.spark.internal.BDDTypeManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager
// @dep_class 699fc0710c61578 soot_jimple_spark_internal_BDDTypeManager

// header file dependencies
// @dep_header soot_jimple_spark_internal_AbstractTypeManager

#include "soot/jimple/spark/internal/AbstractTypeManager.h"

#ifndef _JC_soot_jimple_spark_internal_BDDTypeManager_H_
#define _JC_soot_jimple_spark_internal_BDDTypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_relations_Domain$object;
struct _jc_soot_relations_PhysicalDomain$object;
struct _jc_soot_relations_Relation$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs	_jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$refs	_jc_soot_jimple_spark_internal_BDDTypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs	_jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_BDDTypeManager$object	_jc_soot_jimple_spark_internal_BDDTypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vmethods	_jc_soot_jimple_spark_internal_BDDTypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtable	_jc_soot_jimple_spark_internal_BDDTypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtype	_jc_soot_jimple_spark_internal_BDDTypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$_init$a580f473db5d2f29(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_relations_Relation$object *_jc_soot_jimple_spark_internal_BDDTypeManager$method$get$f657e2659e21a4a6(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$update$1bc19abd93504b5c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_BDDTypeManager$method$updatePair$01330770c59dda9c(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$get$f657e2659e21a4a6;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$makeTypeMask$f36568e0574d6282;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$update$1bc19abd93504b5c;
extern _jc_method _jc_soot_jimple_spark_internal_BDDTypeManager$method_info$updatePair$01330770c59dda9c;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vmethods {
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
	struct _jc_soot_relations_Relation$object	*(*get$f657e2659e21a4a6)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
	void	(*update$1bc19abd93504b5c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *) _JC_JCNI_ATTR;
	void	(*updatePair$01330770c59dda9c)(_jc_env *, struct _jc_soot_jimple_spark_internal_BDDTypeManager$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vmethods	soot_jimple_spark_internal_BDDTypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_BDDTypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs {
	struct _jc_soot_relations_PhysicalDomain$object	*t1;
	struct _jc_soot_relations_PhysicalDomain$object	*t2;
	struct _jc_soot_relations_PhysicalDomain$object	*v1;
	struct _jc_soot_relations_PhysicalDomain$object	*h1;
	struct _jc_soot_relations_Domain$object	*subt;
	struct _jc_soot_relations_Domain$object	*supt;
	struct _jc_soot_relations_Domain$object	*type;
	struct _jc_soot_relations_Domain$object	*var;
	struct _jc_soot_relations_Domain$object	*obj;
	struct _jc_soot_relations_Relation$object	*typeSubtype;
	struct _jc_soot_relations_Relation$object	*varNodeType;
	struct _jc_soot_relations_Relation$object	*newVnType;
	struct _jc_soot_relations_Relation$object	*allocNodeType;
	struct _jc_soot_relations_Relation$object	*newAnType;
	struct _jc_soot_relations_Relation$object	*typeMask;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$refs {
    _jc_soot_jimple_spark_internal_BDDTypeManager$sub_refs	soot_jimple_spark_internal_BDDTypeManager;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs {
	jint	lastAllocNode;
	jint	lastVarNode;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_soot_jimple_spark_internal_BDDTypeManager$sub_nonrefs	soot_jimple_spark_internal_BDDTypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_BDDTypeManager$object {
	_jc_soot_jimple_spark_internal_BDDTypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_BDDTypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_BDDTypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_BDDTypeManager$vtype _jc_soot_jimple_spark_internal_BDDTypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_BDDTypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_BDDTypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_BDDTypeManager_H_ */
